@@ -22,7 +22,7 @@ from . import version
 from .common import HttpResponse, JsonResponse, can_make_public, settings
 from .format_csv import get_csv_rows
 from .models import View
-from .orm_admin import OPEN_IN_ADMIN, get_models
+from .orm_admin import get_models
 from .orm_results import get_result_list, get_result_queryset, get_results
 from .query import BoundQuery, Query, QueryFilter
 from .types import TYPES
@@ -60,7 +60,7 @@ def _get_model_fields(model_name, orm_models):
     orm_model = orm_models[model_name]
 
     def sort_model_fields(fields):
-        front = {orm_model.pk: 1, OPEN_IN_ADMIN: 2}
+        front = {orm_model.pk: 1, settings.DATA_BROWSER_ADMIN_FIELD_NAME.lower(): 2}
         sorted_fields = sorted(
             fields.items(),
             key=lambda name_field: (
@@ -319,10 +319,9 @@ def _data_response(request, query, media, privileged=False, strict=False):
             res = "Not available for pure aggregates"
         else:
             if media == "sql":
-                res = "This is an approximation of the main query.\n"
-                res += (
-                    "Pages with pivoted or calculated data may do additional"
-                    " queries.\n\n"
+                res = (
+                    "/* This is an approximation of the main query.\nPages with pivoted"
+                    " or calculated data may do additional queries. */\n\n"
                 )
                 res += sqlparse.format(
                     str(query_set.query), reindent=True, keyword_case="upper"
@@ -330,10 +329,9 @@ def _data_response(request, query, media, privileged=False, strict=False):
             elif media == "explain":
                 res = query_set.explain()
             elif media == "qs":
-                res = "This is an approximation of the main queryset.\n"
-                res += (
-                    "Pages with pivoted or calculated data may do additional"
-                    " queries.\n\n"
+                res = (
+                    "# This is an approximation of the main queryset.\n# Pages with"
+                    " pivoted or calculated data may do additional queries.\n\n"
                 )
                 res += str(query_set)
             else:
@@ -364,7 +362,7 @@ def proxy_js_dev_server(request, path):  # pragma: no cover
     """
     response = _get_from_js_dev_server(request)
     return http.StreamingHttpResponse(
-        streaming_content=response.iter_content(2 ** 12),
+        streaming_content=response.iter_content(2**12),
         content_type=response.headers.get("Content-Type"),
         status=response.status_code,
         reason=response.reason,
