@@ -6,10 +6,11 @@ from django.contrib.admin.options import BaseModelAdmin
 from django.contrib.auth.models import Permission, User
 from django.utils import timezone
 
-from data_browser.orm_admin import OrmModel, admin_get_queryset, get_models
+from data_browser.orm_admin import OrmModel, get_models
 from data_browser.orm_results import get_results
 from data_browser.query import BoundQuery, Query
 
+from .conftest import POSTGRES
 from .core import models
 from .util import ANY, KEYS
 
@@ -94,17 +95,23 @@ def pivot_products(db):
 
 
 @pytest.fixture
-def orm_models(req):
-    return get_models(req)
+def get_orm_models(admin_ddb_request):
+    return lambda: get_models(admin_ddb_request)
 
 
 @pytest.fixture
-def get_product_pivot(req, orm_models, django_assert_num_queries):
+def orm_models(get_orm_models):
+    return get_orm_models()
+
+
+@pytest.fixture
+def get_product_pivot(admin_ddb_request, get_orm_models, django_assert_num_queries):
     def helper(queries, *args, **kwargs):
+        orm_models = get_orm_models()
         query = Query.from_request("core.Product", *args, **kwargs)
         bound_query = BoundQuery.bind(query, orm_models)
         with django_assert_num_queries(queries):
-            data = get_results(req, bound_query, orm_models, False)
+            data = get_results(admin_ddb_request, bound_query, orm_models, False)
             return {
                 "cols": flatten_table(bound_query.col_fields, data["cols"]),
                 "rows": flatten_table(bound_query.row_fields, data["rows"]),
@@ -163,6 +170,14 @@ def test_get_file_link(get_product_flat):
     sortedAssert(data, [["a", ""], ["b", "/media/bob.jpg"]])
 
 
+def test_filter_file(get_product_flat):
+    producer = models.Producer.objects.create()
+    models.Product.objects.create(name="a", producer=producer, image="fred.jpg")
+    models.Product.objects.create(name="b", producer=producer, image="bob.jpg")
+    data = get_product_flat(1, "name,image", [("image__contains", "ob")])
+    sortedAssert(data, [["b", "/media/bob.jpg"]])
+
+
 def test_get_url_link(get_product_flat):
     producer = models.Producer.objects.create()
     models.Product.objects.create(name="a", producer=producer)
@@ -171,7 +186,7 @@ def test_get_url_link(get_product_flat):
     sortedAssert(data, [["a", None], ["b", "www.google.com"]])
 
 
-def test_bad_storage(monkeypatch, req):
+def test_bad_storage(monkeypatch, admin_ddb_request):
     # break storage
     from django.core.files.storage import FileSystemStorage, default_storage
     from django.utils.functional import empty
@@ -183,12 +198,12 @@ def test_bad_storage(monkeypatch, req):
     default_storage._wrapped = empty
 
     # copy what the fixture does
-    orm_models = get_models(req)
+    orm_models = get_models(admin_ddb_request)
 
     def get_product_flat(*args, **kwargs):
         query = Query.from_request("core.Product", *args)
         bound_query = BoundQuery.bind(query, orm_models)
-        data = get_results(req, bound_query, orm_models, False)
+        data = get_results(admin_ddb_request, bound_query, orm_models, False)
         return flatten_table(bound_query.fields, data["rows"])
 
     # some storage backends will hard fail if their underlying storage isn't
@@ -218,23 +233,21 @@ def test_get_calculated_boolean_field_on_admin(get_product_flat):
     sortedAssert(data, [[True], [True], [True]])
 
 
-def test_get_annotated_field_at_base(products, get_product_flat, mocker):
-    mock = mocker.patch(
-        "data_browser.orm_admin.admin_get_queryset", wraps=admin_get_queryset
-    )
+def test_get_annotated_field_at_base(
+    products, get_product_flat, mock_admin_get_queryset
+):
     data = get_product_flat(1, "annotated+1,size-2", [("annotated__not_equals", "a")])
     assert data == [["b", 1], ["c", 2]]
-    assert len(mock.call_args_list) == 2
+    assert len(mock_admin_get_queryset.call_args_list) == 6  # 4 for setup, 2 for query
 
 
 @pytest.mark.skipif(django.VERSION < (2, 1), reason="Django version 2.1 required")
-def test_get_aggretated_annotated_field_at_base(products, get_product_flat, mocker):
-    mock = mocker.patch(
-        "data_browser.orm_admin.admin_get_queryset", wraps=admin_get_queryset
-    )
+def test_get_aggretated_annotated_field_at_base(
+    products, get_product_flat, mock_admin_get_queryset
+):
     data = get_product_flat(1, "annotated__count+1,size-2", [])
     assert data == [[2, 1], [1, 2]]  # aggregates last
-    assert len(mock.call_args_list) == 2
+    assert len(mock_admin_get_queryset.call_args_list) == 6  # 4 for setup, 2 for query
 
 
 @pytest.mark.skipif(django.VERSION < (2, 1), reason="Django version 2.1 required")
@@ -253,45 +266,41 @@ def test_filter_and_select_annotation_function(products, get_product_flat):
     assert data == [["NotNull", 1], ["NotNull", 2]]
 
 
-def test_get_annotated_field_function_at_base(products, get_product_flat, mocker):
-    mock = mocker.patch(
-        "data_browser.orm_admin.admin_get_queryset", wraps=admin_get_queryset
-    )
+def test_get_annotated_field_function_at_base(
+    products, get_product_flat, mock_admin_get_queryset
+):
     data = get_product_flat(1, "annotated__is_null+1,size-2", [])
     assert data == [["NotNull", 2.0], ["NotNull", 1.0]]
-    assert len(mock.call_args_list) == 2
+    assert len(mock_admin_get_queryset.call_args_list) == 6  # 4 for setup, 2 for query
 
 
-def test_get_annotated_field_down_tree(products, get_product_flat, mocker):
-    mock = mocker.patch(
-        "data_browser.orm_admin.admin_get_queryset", wraps=admin_get_queryset
-    )
+def test_get_annotated_field_down_tree(
+    products, get_product_flat, mock_admin_get_queryset
+):
     data = get_product_flat(
         1,
         "producer__address__andrew+2,size-1",
         [("producer__address__andrew__not_equals", "bad")],
     )
     assert data == [[None, 2.0], ["good", 1]]
-    assert len(mock.call_args_list) == 2
+    assert len(mock_admin_get_queryset.call_args_list) == 6  # 4 for setup, 2 for query
 
 
 @pytest.mark.skipif(django.VERSION < (2, 1), reason="Django version 2.1 required")
-def test_get_aggregated_annotated_field_down_tree(products, get_product_flat, mocker):
-    mock = mocker.patch(
-        "data_browser.orm_admin.admin_get_queryset", wraps=admin_get_queryset
-    )
+def test_get_aggregated_annotated_field_down_tree(
+    products, get_product_flat, mock_admin_get_queryset
+):
     data = get_product_flat(1, "producer__address__andrew__count+1,size-2", [])
     assert data == [[2, 0], [1, 2]]  # aggregates last
-    assert len(mock.call_args_list) == 2
+    assert len(mock_admin_get_queryset.call_args_list) == 6  # 4 for setup, 2 for query
 
 
-def test_get_annotated_field_function_down_tree(products, get_product_flat, mocker):
-    mock = mocker.patch(
-        "data_browser.orm_admin.admin_get_queryset", wraps=admin_get_queryset
-    )
+def test_get_annotated_field_function_down_tree(
+    products, get_product_flat, mock_admin_get_queryset
+):
     data = get_product_flat(1, "producer__address__andrew__is_null+1,size-2", [])
     assert data == [["NotNull", 1.0], ["IsNull", 2.0]]
-    assert len(mock.call_args_list) == 2
+    assert len(mock_admin_get_queryset.call_args_list) == 6  # 4 for setup, 2 for query
 
 
 @pytest.mark.usefixtures("products")
@@ -387,6 +396,20 @@ def test_get_aggregate(get_product_flat):
     assert data == [["g", 3]]
 
 
+@pytest.mark.usefixtures("products")
+@pytest.mark.skipif(not POSTGRES, reason="Postgres specific feature")
+def test_get_all_aggregate(get_product_flat):
+    data = get_product_flat(1, "size_unit,size__all", [])
+    assert data == [["g", "[1.0, 2.0]"]]
+
+
+def test_get_aggregate_underscore(products, get_product_flat):
+    products[0]._underscore = 1
+    products[0].save()
+    data = get_product_flat(1, "size_unit,_underscore__count", [])
+    assert data == [["g", 1]]
+
+
 @pytest.mark.usefixtures("products")
 def test_get_time_aggregate(get_product_flat):
     data = get_product_flat(1, "size_unit,created_time__count", [])
@@ -542,18 +565,24 @@ def test_get_results_string_filter(get_product_flat):
 
 @pytest.mark.usefixtures("products")
 def test_get_results_basic_flat(get_product_flat):
-    # just a query
     data = get_product_flat(1, "name+0,producer__address__city", [])
     assert data == [["a", "london"], ["b", "london"], ["c", None]]
 
 
 @pytest.mark.usefixtures("products")
 def test_get_results_one_to_one(get_product_flat):
-    # just a query
     data = get_product_flat(1, "name+0,producer__address__producer__address__city", [])
     assert data == [["a", "london"], ["b", "london"], ["c", None]]
 
 
+@pytest.mark.usefixtures("products")
+def test_get_results_many_to_one(get_product_flat, mocker):
+    mocker.patch("data_browser.orm_admin.get_feature_flag", return_value=True)
+
+    data = get_product_flat(1, "name+0,producer__products__name+1", [])
+    assert data == [["a", "a"], ["b", "b"], ["c", "c"]]
+
+
 @pytest.mark.usefixtures("products")
 def test_get_results_calculated_causes_query(get_product_flat):
     # query products, fetch objects for calculated
@@ -760,18 +789,18 @@ def test_get_fields(orm_models):
 
 
 class TestPermissions:
-    def get_fields_with_perms(self, rf, perms):
+    def get_fields_with_perms(self, ddb_request, perms):
         user = User.objects.create()
         for perm in perms:
             user.user_permissions.add(Permission.objects.get(codename=f"change_{perm}"))
 
-        request = rf.get("/")
-        request.user = user
-        return get_models(request)
+        ddb_request.user = user
+        return get_models(ddb_request)
 
-    def test_all_perms(self, rf, admin_user):
+    @pytest.mark.django_db
+    def test_all_perms(self, ddb_request):
         orm_models = self.get_fields_with_perms(
-            rf, ["normal", "notinadmin", "inadmin", "inlineadmin"]
+            ddb_request, ["normal", "notinadmin", "inadmin", "inlineadmin"]
         )
 
         assert "core.NotInAdmin" not in orm_models
@@ -790,8 +819,8 @@ class TestPermissions:
         )
 
     @pytest.mark.django_db
-    def test_no_perms(self, rf):
-        orm_models = self.get_fields_with_perms(rf, ["normal"])
+    def test_no_perms(self, ddb_request):
+        orm_models = self.get_fields_with_perms(ddb_request, ["normal"])
 
         assert "core.NotInAdmin" not in orm_models
         assert "core.InAdmin" not in orm_models
@@ -805,8 +834,8 @@ class TestPermissions:
         )
 
     @pytest.mark.django_db
-    def test_inline_perms(self, rf):
-        orm_models = self.get_fields_with_perms(rf, ["normal", "inlineadmin"])
+    def test_inline_perms(self, ddb_request):
+        orm_models = self.get_fields_with_perms(ddb_request, ["normal", "inlineadmin"])
 
         assert "core.NotInAdmin" not in orm_models
         assert "core.InAdmin" not in orm_models
@@ -820,8 +849,8 @@ class TestPermissions:
         )
 
     @pytest.mark.django_db
-    def test_admin_perms(self, rf):
-        orm_models = self.get_fields_with_perms(rf, ["normal", "inadmin"])
+    def test_admin_perms(self, ddb_request):
+        orm_models = self.get_fields_with_perms(ddb_request, ["normal", "inadmin"])
 
         assert "core.NotInAdmin" not in orm_models
         assert orm_models["core.InAdmin"] == OrmModel(
