@@ -9,8 +9,8 @@ from django.utils import timezone
 
 import data_browser.models
 
+from .conftest import SQLITE
 from .core import models
-from .util import update_fe_fixture
 
 
 def dump(val):
@@ -47,16 +47,19 @@ def pivot_products(db):
 @pytest.mark.skipif(django.VERSION < (2, 2), reason="Django version 2.2 required")
 def test_query_html(admin_client, snapshot):
     res = admin_client.get(
-        "/data_browser/query/core.Product/size-0,name+1,size_unit.html?size__lt=2&id__gt=0"
+        "/data_browser/query/core.Product/size-0,name+1,size_unit.html"
+        "?size__lt=2&id__gt=0"
     )
     assert res.status_code == 200
     config = json.loads(res.context["config"])
-    snapshot.assert_match(config, "config")
+    if SQLITE:
+        snapshot.assert_match(config, "config")
 
 
 def test_query_query(admin_client, snapshot):
     res = admin_client.get(
-        "/data_browser/query/core.Product/size-0,name+1,size_unit.query?size__lt=2&id__gt=0"
+        "/data_browser/query/core.Product/size-0,name+1,size_unit.query"
+        "?size__lt=2&id__gt=0"
     )
     assert res.status_code == 200
     query = json.loads(res.content.decode("utf-8"))
@@ -65,9 +68,11 @@ def test_query_query(admin_client, snapshot):
 
 @pytest.mark.parametrize("format", ["sql", "profile", "pstats", "profile_sql", "qs"])
 def test_query_misc_formats(admin_client, format):
-    # we're not going to check the result as they vary and it's sufficient that it doesn't blow up
+    # we're not going to check the result as they vary and it's sufficient that it
+    # doesn't blow up
     res = admin_client.get(
-        f"/data_browser/query/core.Product/size-0,name+1,size_unit.{format}?size__lt=2&id__gt=0"
+        f"/data_browser/query/core.Product/size-0,name+1,size_unit.{format}"
+        "?size__lt=2&id__gt=0"
     )
     assert res.status_code == 200
 
@@ -75,7 +80,8 @@ def test_query_misc_formats(admin_client, format):
 @pytest.mark.skipif(django.VERSION < (2, 1), reason="Django version 2.1 required")
 def test_query_explain(admin_client):
     res = admin_client.get(
-        "/data_browser/query/core.Product/size-0,name+1,size_unit.explain?size__lt=2&id__gt=0"
+        "/data_browser/query/core.Product/size-0,name+1,size_unit.explain"
+        "?size__lt=2&id__gt=0"
     )
     assert res.status_code == 200
 
@@ -98,7 +104,8 @@ def test_query_qs_variants(admin_client, snapshot):
 )
 def test_query_bad_formats(admin_client, format):
     res = admin_client.get(
-        f"/data_browser/query/core.Product/size-0,name+1,size_unit.{format}?size__lt=2&id__gt=0"
+        f"/data_browser/query/core.Product/size-0,name+1,size_unit.{format}"
+        "?size__lt=2&id__gt=0"
     )
     assert res.status_code == 404
 
@@ -110,7 +117,8 @@ def test_query_html_no_perms(admin_user, admin_client, snapshot):
     res = admin_client.get("/data_browser/query//.html?")
     assert res.status_code == 200
     config = json.loads(res.context["config"])
-    snapshot.assert_match(config, "config")
+    if SQLITE:
+        snapshot.assert_match(config, "config")
 
 
 @pytest.mark.skipif(django.VERSION < (2, 2), reason="Django version 2.2 required")
@@ -118,8 +126,8 @@ def test_query_ctx(admin_client, snapshot):
     res = admin_client.get("/data_browser/query//.ctx?")
     assert res.status_code == 200
     config = res.json()
-    snapshot.assert_match(config, "config")
-    update_fe_fixture("frontend/src/context_fixture.json", config)
+    if SQLITE:
+        snapshot.assert_match(config, "config")
 
 
 @pytest.mark.skipif(django.VERSION < (2, 2), reason="Django version 2.2 required")
@@ -128,20 +136,16 @@ def test_query_ctx_m2m(admin_client, snapshot, mocker):
     res = admin_client.get("/data_browser/query//.ctx?")
     assert res.status_code == 200
     config = res.json()
-    snapshot.assert_match(config, "config")
-    update_fe_fixture("frontend/src/context_fixture.json", config)
+    if SQLITE:
+        snapshot.assert_match(config, "config")
 
 
 @pytest.mark.usefixtures("products")
 def test_query_json_bad_fields(admin_client):
     res = admin_client.get(
-        "".join(
-            [
-                "/data_browser/query/core.Product/",
-                "size-0,name+1,size_unit,bob-2,is_onsale,pooducer__name,producer__name.json",
-                "?size__lt=2&id__gt=0&bob__gt=1&size__xx=1&size__lt=xx",
-            ]
-        )
+        "/data_browser/query/core.Product/"
+        "size-0,name+1,size_unit,bob-2,is_onsale,pooducer__name,producer__name.json"
+        "?size__lt=2&id__gt=0&bob__gt=1&size__xx=1&size__lt=xx"
     )
     assert res.status_code == 200
     assert json.loads(res.content.decode("utf-8"))["rows"] == [
@@ -164,7 +168,8 @@ def test_query_json_bad_fields(admin_client):
 
 def test_query_bad_media(admin_client):
     res = admin_client.get(
-        "/data_browser/query/core.Product/size-0,name+1,size_unit.bob?size__lt=2&id__gt=0"
+        "/data_browser/query/core.Product/size-0,name+1,size_unit.bob"
+        "?size__lt=2&id__gt=0"
     )
     assert res.status_code == 404
 
@@ -172,7 +177,8 @@ def test_query_bad_media(admin_client):
 @pytest.mark.usefixtures("products")
 def test_query_csv(admin_client):
     res = admin_client.get(
-        "/data_browser/query/core.Product/size-0,name+1,size_unit.csv?size__lt=2&id__gt=0"
+        "/data_browser/query/core.Product/size-0,name+1,size_unit.csv"
+        "?size__lt=2&id__gt=0"
     )
     assert res.status_code == 200
     res = res.getvalue().decode("utf-8")
@@ -185,7 +191,8 @@ def test_query_csv(admin_client):
 @pytest.mark.usefixtures("pivot_products")
 def test_query_csv_pivoted(admin_client):
     res = admin_client.get(
-        "/data_browser/query/core.Product/created_time__year+0,&created_time__month+1,id__count,size__max.csv?"
+        "/data_browser/query/core.Product/"
+        "created_time__year+0,&created_time__month+1,id__count,size__max.csv?"
     )
     assert res.status_code == 200
     res = res.getvalue().decode("utf-8")
@@ -201,22 +208,22 @@ def test_query_csv_pivoted(admin_client):
 
 
 testdata = [
-    ("----"),
-    ("---b"),
-    ("--c-"),
-    ("--cb"),
-    ("-r--"),
-    ("-r-b"),
-    ("-rc-"),
-    ("-rcb"),
-    ("d---"),
-    ("d--b"),
-    ("d-c-"),
-    ("d-cb"),
-    ("dr--"),
-    ("dr-b"),
-    ("drc-"),
-    ("drcb"),
+    "----",
+    "---b",
+    "--c-",
+    "--cb",
+    "-r--",
+    "-r-b",
+    "-rc-",
+    "-rcb",
+    "d---",
+    "d--b",
+    "d-c-",
+    "d-cb",
+    "dr--",
+    "dr-b",
+    "drc-",
+    "drcb",
 ]
 
 
@@ -246,7 +253,8 @@ def test_query_csv_pivot_permutations(admin_client, key, snapshot):
 @pytest.mark.usefixtures("products")
 def test_query_json(admin_client, snapshot):
     res = admin_client.get(
-        "/data_browser/query/core.Product/size-0,name+1,size_unit.json?size__lt=2&id__gt=0"
+        "/data_browser/query/core.Product/size-0,name+1,size_unit.json"
+        "?size__lt=2&id__gt=0"
     )
     assert res.status_code == 200
     data = json.loads(res.content.decode("utf-8"))
@@ -266,7 +274,8 @@ def test_query_is_null_date_filter(admin_client, snapshot):
 @pytest.mark.usefixtures("pivot_products")
 def test_query_json_pivot(admin_client, snapshot):
     res = admin_client.get(
-        "/data_browser/query/core.Product/created_time__year+0,&created_time__month+1,id__count,size__max.json?"
+        "/data_browser/query/core.Product/"
+        "created_time__year+0,&created_time__month+1,id__count,size__max.json?"
     )
     assert res.status_code == 200
     data = json.loads(res.content.decode("utf-8"))
@@ -282,7 +291,7 @@ def test_query_json_bad_model(admin_client):
 
 
 @pytest.mark.usefixtures("products")
-def test_view_csv(admin_client, settings):
+def test_view_csv(admin_client, settings, mock_admin_get_queryset):
     view = data_browser.models.View.objects.create(
         model_name="core.Product",
         fields="size-0,name+1,size_unit",
@@ -297,6 +306,7 @@ def test_view_csv(admin_client, settings):
     view.save()
     res = admin_client.get(f"/data_browser/view/{view.public_slug}.csv")
     assert res.status_code == 200
+    assert mock_admin_get_queryset.call_args[0][1].data_browser["public_view"]
     res = res.getvalue().decode("utf-8")
     dump(res)
     rows = list(csv.reader(res.splitlines()))
